==> ask_sdk_model-1.16.0-py2.py3-none-any.whl: ask_sdk_model/interfaces/connections/v1/start_connection_directive.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum
from ask_sdk_model.directive import Directive


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union
    from datetime import datetime


class StartConnectionDirective(Directive):
    """
    This is the directive that a skill can send as part of their response to a session based request to start a connection. A response will be returned to the skill when the connection is handled.


    :param uri: This defines the name and version of connection that the requester is trying to send. The format of the uri should follow this pattern: connection://connectionName/connectionVersion. Invalid uri will cause an error which will be sent back to the requester.
    :type uri: (optional) str
    :param input: This is the input to the connection that the requester is trying to send. It is predefined by the handler of the connection. If the input format is incorrect, an error will be sent to to the requester.
    :type input: (optional) dict(str, object)
    :param token: This is an echo back string that requester will receive it when it gets resumed. It is never sent to the handler of the connection.
    :type token: (optional) str

    """
    deserialized_types = {
        'object_type': 'str',
        'uri': 'str',
        'input': 'dict(str, object)',
        'token': 'str'
    }  # type: Dict

    attribute_map = {
        'object_type': 'type',
        'uri': 'uri',
        'input': 'input',
        'token': 'token'
    }  # type: Dict

    def __init__(self, uri=None, input=None, token=None):
        # type: (Optional[str], Optional[Dict[str, object]], Optional[str]) -> None
        """This is the directive that a skill can send as part of their response to a session based request to start a connection. A response will be returned to the skill when the connection is handled.

        :param uri: This defines the name and version of connection that the requester is trying to send. The format of the uri should follow this pattern: connection://connectionName/connectionVersion. Invalid uri will cause an error which will be sent back to the requester.
        :type uri: (optional) str
        :param input: This is the input to the connection that the requester is trying to send. It is predefined by the handler of the connection. If the input format is incorrect, an error will be sent to to the requester.
        :type input: (optional) dict(str, object)
        :param token: This is an echo back string that requester will receive it when it gets resumed. It is never sent to the handler of the connection.
        :type token: (optional) str
        """
        self.__discriminator_value = "Connections.StartConnection"  # type: str

        self.object_type = self.__discriminator_value
        super(StartConnectionDirective, self).__init__(object_type=self.__discriminator_value)
        self.uri = uri
        self.input = input
        self.token = token

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, StartConnectionDirective):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask_sdk_model-1.27.0-py2.py3-none-any.whl: ask_sdk_model/interfaces/connections/v1/start_connection_directive.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum
from ask_sdk_model.directive import Directive


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union
    from datetime import datetime
    from ask_sdk_model.interfaces.connections.on_completion import OnCompletion


class StartConnectionDirective(Directive):
    """
    This is the directive that a skill can send as part of their response to a session based request to start a connection. A response will be returned to the skill when the connection is handled.


    :param uri: This defines the name and version of connection that the requester is trying to send. The format of the uri should follow this pattern: connection://connectionName/connectionVersion. Invalid uri will cause an error which will be sent back to the requester.
    :type uri: (optional) str
    :param on_completion: 
    :type on_completion: (optional) ask_sdk_model.interfaces.connections.on_completion.OnCompletion
    :param input: This is the input to the connection that the requester is trying to send. It is predefined by the handler of the connection. If the input format is incorrect, an error will be sent to to the requester.
    :type input: (optional) dict(str, object)
    :param token: This is an echo back string that requester will receive it when it gets resumed. It is never sent to the handler of the connection.
    :type token: (optional) str

    """
    deserialized_types = {
        'object_type': 'str',
        'uri': 'str',
        'on_completion': 'ask_sdk_model.interfaces.connections.on_completion.OnCompletion',
        'input': 'dict(str, object)',
        'token': 'str'
    }  # type: Dict

    attribute_map = {
        'object_type': 'type',
        'uri': 'uri',
        'on_completion': 'onCompletion',
        'input': 'input',
        'token': 'token'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, uri=None, on_completion=None, input=None, token=None):
        # type: (Optional[str], Optional[OnCompletion], Optional[Dict[str, object]], Optional[str]) -> None
        """This is the directive that a skill can send as part of their response to a session based request to start a connection. A response will be returned to the skill when the connection is handled.

        :param uri: This defines the name and version of connection that the requester is trying to send. The format of the uri should follow this pattern: connection://connectionName/connectionVersion. Invalid uri will cause an error which will be sent back to the requester.
        :type uri: (optional) str
        :param on_completion: 
        :type on_completion: (optional) ask_sdk_model.interfaces.connections.on_completion.OnCompletion
        :param input: This is the input to the connection that the requester is trying to send. It is predefined by the handler of the connection. If the input format is incorrect, an error will be sent to to the requester.
        :type input: (optional) dict(str, object)
        :param token: This is an echo back string that requester will receive it when it gets resumed. It is never sent to the handler of the connection.
        :type token: (optional) str
        """
        self.__discriminator_value = "Connections.StartConnection"  # type: str

        self.object_type = self.__discriminator_value
        super(StartConnectionDirective, self).__init__(object_type=self.__discriminator_value)
        self.uri = uri
        self.on_completion = on_completion
        self.input = input
        self.token = token

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, StartConnectionDirective):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
